### Ecoworthy logger

Tired of your batteries connecting to arbitrary Chinese servers? Well look no further. This is a simple utility that connects via Bluetooth
to your Ecoworthy batteries and exposes them either via a simple command line log, or via Prometheus for use in Grafana, etc.

This can be useful when setting up dashboards to monitor battery balance, thermals, and state of charge.

Bluetooth only for now; feel free to contribute CAN/RS485 support.

#### Tested batteries

- Ecoworthy 48V Server Rack Batteries - V3

#### Tested hardware

- Raspberry Pi Zero W

Anything that supports Bluetooth should theoretically work.
